@@ -1,4 +1,4 @@
-import time, pyperclip, os, darkdetect, threading
+import time, pyperclip, os, darkdetect, threading, winshell
 from kivy import Config
 from kivy.uix.boxlayout import BoxLayout
 from kivymd.uix.button import MDFlatButton
@@ -15,9 +15,10 @@ from kivy.uix.settings import ContentPanel
 from kivymd.app import MDApp
 from screeninfo import get_monitors
 from kivy.properties import *
+from win32com.client import Dispatch
 
 
-class ContentKivy4(BoxLayout):
+class Content(BoxLayout):
     pass
 
 
@@ -104,7 +105,7 @@ class Kivy4(MDApp):
                  screen_size=None, minimum=None, center: bool = True,
                  sun_icon: str = 'white-balance-sunny', moon_icon: str = 'weather-night',
                  main_color: str = 'Blue', icon: str = '', toolbar=False, app_data: bool = True,
-                 disable_x: bool = False, pre_string: str = '', **kwargs):
+                 disable_x: bool = False, pre_string: str = '', toolbar_name: str = None, **kwargs):
 
         super().__init__(**kwargs)
 
@@ -112,7 +113,7 @@ class Kivy4(MDApp):
             minimum = [0.1, 0.1]
 
         self.app_name = app_name
-        self.builder_string = '''<ContentKivy4>
+        self.builder_string = '''<Content>
     orientation: "vertical"
     spacing: "12dp"
     size_hint_y: None
@@ -128,7 +129,7 @@ class Kivy4(MDApp):
             self.isDarkMode()
 
         self.dialog = None
-        self.setProperties(main_color, icon, toolbar, string, pre_string)
+        self.setProperties(main_color, icon, toolbar, string, pre_string, toolbar_name)
         self.disable_x = disable_x
 
         screen = get_monitors()[0]
@@ -139,7 +140,7 @@ class Kivy4(MDApp):
 
         self.run()
 
-    def setProperties(self, main_color, icon, toolbar, string, pre_string):
+    def setProperties(self, main_color, icon, toolbar, string, pre_string, toolbar_name):
 
         for x in pre_string.split('\n'):
             if 'x,y=' in x.replace(' ', '') and '#' not in x:
@@ -151,7 +152,7 @@ class Kivy4(MDApp):
         self.builder_string += self.custom_classes()
 
         if toolbar:
-            self.builder_string += self.getToolbar(toolbar)
+            self.builder_string += self.getToolbar(toolbar, toolbar_name)
 
             for x in string.split('\n'):
                 if 'x,y=' in x.replace(' ', '') and '#' not in x:
@@ -228,9 +229,18 @@ class Kivy4(MDApp):
     def setFile(self, file, value, extension='.txt'):
         path_to_create = f'{self.appdata_path}/{file}{extension}'
 
+        if isinstance(value, int):
+            value_to_save = f'<$i>{value}'
+
+        elif isinstance(value, float):
+            value_to_save = f'<$f>{value}'
+
+        else:
+            value_to_save = str(value)
+
         try:
             with open(path_to_create, 'w') as f:
-                f.write(value)
+                f.write(value_to_save)
 
         except Exception as e:
             print(e)
@@ -241,21 +251,35 @@ class Kivy4(MDApp):
 
         try:
             with open(path_of_file, 'r') as f:
-                return f.read()
+                value = f.read()
+
+                if not value.startswith('<$'):
+                    return value
+
+                if value.startswith('<$i>'):
+                    return int(value.lstrip('<$i>'))
+
+                elif value.startswith('<$f>'):
+                    return float(value.lstrip('<$i>'))
+
+                return value
 
         except FileNotFoundError:
             if create_file_if_not_exist:
-                with open(path_of_file, 'w') as f:
-                    f.write(default)
-                    return default
+                self.setFile(file, default)
 
-            else:
-                return default
+            return default
 
         except Exception as e:
             print(e)
             return default
 
+    def get_file(self, *args):
+        self.getFile(*args)
+
+    def set_file(self, *args):
+        self.setFile(*args)
+
     def isDarkMode(self, filename='dark mode.txt'):
         try:
             with open(self.appdata_path + '/' + filename, 'r') as f:
@@ -316,9 +340,10 @@ class Kivy4(MDApp):
 
         self.theme_cls.theme_style = value
 
-    def getToolbar(self, properties: list):
+    def getToolbar(self, properties: list, toolbar_name: str):
+
         if properties == True:
-            right_icons, left_icons, name = '[[app.dark_mode_icon, lambda x: app.reverseDarkMode()]]', '[]', self.app_name
+            right_icons, left_icons = '[[app.dark_mode_icon, lambda x: app.reverseDarkMode()]]', '[]'
 
         elif len(properties) == 2:
             left_icons, right_icons, name = properties[0], properties[1], self.app_name
@@ -327,8 +352,11 @@ class Kivy4(MDApp):
         else:
             left_icons, right_icons, name = properties
 
-        self.left_icons = ListProperty(left_icons)
-        self.right_icons = ListProperty(right_icons)
+        if toolbar_name:
+            name = toolbar_name
+
+        else:
+            name = self.app_name
 
         return f'''
 Screen:
@@ -337,8 +365,8 @@ Screen:
         pos_hint: {{"top": 1}}
         elevation: 10
         title: "{name}"
-        right_action_items: {self.left_icons}
-        left_action_items: {self.right_icons}
+        right_action_items: {right_icons}
+        left_action_items: {left_icons}
 
     MDNavigationLayout:
         x: toolbar.height
@@ -374,13 +402,11 @@ Screen:
         return '''
 <Text@MDLabel>:
     halign: 'center'
-    font_name: 'arial'
 
 <Input@MDTextField>:
     mode: "rectangle"
     text: ""
     size_hint_x: 0.5
-    font_name: 'arial'
 
 <Check@MDCheckbox>:
     group: 'group'
@@ -389,11 +415,9 @@ Screen:
 
 <Btn@MDFillRoundFlatButton>:
     text: ""
-    font_name: 'arial'
 
 <BtnIcon@MDFillRoundFlatIconButton>:
     text: ""
-    font_name: 'arial'
 
 <Img@Image>:    
     allow_stretch: True
@@ -422,8 +446,8 @@ Screen:
     def on_cancel_picker(self, instance, value):
         pass
 
-    def popup_kivy4(self, title='My popup', content=ContentKivy4(), cancel_text='CANCEL', okay_text='OKAY',
-              okay_func=lambda *args: print('yes'), cancel_func=None):
+    def popup_kivy4(self, title='My popup', content=Content(), cancel_text='CANCEL', okay_text='OKAY',
+                    okay_func=lambda *args: print('yes'), cancel_func=None):
 
         if cancel_func is None:
             cancel_func = lambda *args: self.dismiss()
@@ -458,6 +482,26 @@ Screen:
         except Exception as e:
             print(e)
 
+    def create_shortcut(self, source=__file__, target=None, name=None, only_exe=True):
 
-    def updateToolbar(self, lst):
-        self.left_icons, self.right_icons = lst
\ No newline at end of file
+        if not only_exe and source.endswith('.exe'):
+            return 'Source file is not exe'
+
+        if not target:
+            target = self.get_shell_startup()
+
+        if not name:
+            name = self.app_name
+
+        path = rf"{target}\{name}.lnk"
+        work_dir = os.path.dirname(source)
+
+        shell = Dispatch('WScript.Shell')
+        shortcut = shell.CreateShortCut(path)
+        shortcut.Targetpath = source
+        shortcut.WorkingDirectory = work_dir
+        shortcut.save()
+
+    @staticmethod
+    def get_shell_startup():
+        return os.path.join(os.getenv("appdata"), "Microsoft", "Windows", "Start Menu", "Programs", "Startup")
